**twpy** was designed to be the *best* desktop GUI client for editing and managing **TiddlyWiki** files.

Installation is as simple as: 

`pip install tiddlywiki`

Two terminal commands are installed:

**twpym** for starting the **twpy** TiddlyWiki Manager. **--verbose** is an option. You can open TiddlyWiki files in the Editor from the Manager.

**twpye** for starting the **twpy** TiddlyWiki Editor. Requires **--file your-tiddly-wiki-path.html** option. **--verbose** is also an option. 
